@@ -29,6 +29,7 @@ class DingDingPlugin(NotificationPlugin):
     title = 'WbDingDing'
     conf_key = slug
     conf_title = title
+    isAtALL = false
     project_conf_form = DingDingOptionsForm
 
     def is_configured(self, project):
@@ -53,6 +54,7 @@ class DingDingPlugin(NotificationPlugin):
         access_token = self.get_option('access_token', group.project)
         send_url = DingTalk_API.format(token=access_token)
         title = u'【%s】的项目异常' % event.project.slug
+        isAtALL = bool(event.get_tag('errorLevel')=='P0')
 
         data = {
             "msgtype": "markdown",
@@ -68,7 +70,7 @@ class DingDingPlugin(NotificationPlugin):
                 )
             },
             "at": {
-                "isAtALL": event.get_tag('errorLevel')=="P0"
+                "isAtALL": isAtALL
             }
         }
 
